==> haskell-singleton-bool-0.1.8-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-DmNbasf4vh68OU73RZDccf
key:                  singleton-bool-0.1.8-DmNbasf4vh68OU73RZDccf
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  bfdafd9cdaffa71f5b67b729c190ffba
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-DmNbasf4vh68OU73RZDccf
depends:
    base-4.18.2.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    dec-0.0.6-263DLNY3k7iJhcZSv4mNkm deepseq-1.4.8.1
    some-1.0.6-cBl1TQWrgGHtAYCHe6T1Z

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.8-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-7V7lKgkPwFG9VIEMQz0TCn
key:                  singleton-bool-0.1.8-7V7lKgkPwFG9VIEMQz0TCn
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  b8a1847cdb2ddce1728a38bee74ce8f2
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-7V7lKgkPwFG9VIEMQz0TCn
depends:
    base-4.18.2.1 boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA
    dec-0.0.6-263DLNY3k7iJhcZSv4mNkm deepseq-1.4.8.1
    some-1.0.6-HFFgyqBBv6iIpnKoe58AFz

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
